pub trait RemoteCapabilityInvoker: Send + Sync {
// Required method
fn invoke_remote(
&self,
peer: &PeerRecord,
request: &CapabilityRequest,
) -> CapabilityResult<CapabilityResponse>;
}Expand description
Adapter used to invoke a capability hosted by a remote runtime peer.
Required Methods
Sourcefn invoke_remote(
&self,
peer: &PeerRecord,
request: &CapabilityRequest,
) -> CapabilityResult<CapabilityResponse>
fn invoke_remote( &self, peer: &PeerRecord, request: &CapabilityRequest, ) -> CapabilityResult<CapabilityResponse>
Sends one request to the selected peer and returns its response.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".